package com.fs.qw.service;

import com.fs.qw.domain.QwAppContactWayLogs;
import com.fs.qw.param.QwAppContactWayLogsParam;
import com.fs.qw.vo.QwAppContactWayLogsListVO;

import java.util.List;

/**
 * 联系我日志Service接口
 *
 * @author fs
 * @date 2024-12-11
 */
public interface IQwAppContactWayLogsService
{
    /**
     * 查询联系我日志
     *
     * @param id 联系我日志主键
     * @return 联系我日志
     */
    public QwAppContactWayLogs selectQwAppContactWayLogsById(Long id);

    /**
     * 查询联系我日志列表
     *
     * @param qwAppContactWayLogs 联系我日志
     * @return 联系我日志集合
     */
    public List<QwAppContactWayLogs> selectQwAppContactWayLogsList(QwAppContactWayLogs qwAppContactWayLogs);

    /**
     * 新增联系我日志
     *
     * @param qwAppContactWayLogs 联系我日志
     * @return 结果
     */
    public int insertQwAppContactWayLogs(QwAppContactWayLogs qwAppContactWayLogs);

    /**
     * 修改联系我日志
     *
     * @param qwAppContactWayLogs 联系我日志
     * @return 结果
     */
    public int updateQwAppContactWayLogs(QwAppContactWayLogs qwAppContactWayLogs);

    /**
     * 批量删除联系我日志
     *
     * @param ids 需要删除的联系我日志主键集合
     * @return 结果
     */
    public int deleteQwAppContactWayLogsByIds(Long[] ids);

    /**
     * 删除联系我日志信息
     *
     * @param id 联系我日志主键
     * @return 结果
     */
    public int deleteQwAppContactWayLogsById(Long id);

    List<QwAppContactWayLogsListVO> selectQwAppContactWayLogsListVO(QwAppContactWayLogsParam qwAppContactWayLogs);

}
